prism.membersFilter = function (widget, options) {

	//////////////////////////////////
	//	Registering widget events	//
	//////////////////////////////////

	//	Define the supported widget types
	var supportedWidgets = ["column/classic","column/stackedcolumn","bar/classic","bar/stacked","line/basic","line/spline","area/stacked","area/basic"];

	//	Function to ensure widget will work
	function widgetCheck(widget,args){

		//	Assume true to start
		var isValid = true;

		//Make sure at least 1 value is defined
		if (!args.result.series) {
			isValid = false;
		}

		//	Make sure the chart type is supported
		if (supportedWidgets.indexOf(widget.subtype)<0){
			isValid = false;
		}

		return isValid
	}

	widget.on('processresult', function(widget, args) {
		
		//	Make sure we should continue
		if (!widgetCheck) {
			return
		}

		//	Get the new xAxis categories
		//var buckets = args.result.xAxis.plotBands;
		var buckets = $.grep(args.result.xAxis.plotBands, function(w) {
			return !(isNaN(w.from) || isNaN(w.to));
		});

		//	Create temp array for holding data series
		var allSeries = new Array(args.result.series.length);

		//	Recreate the categories on the xAxis
		args.result.xAxis.categories = [];
		
		$.each(buckets, function(k){

			//	Grab the label
			var label = this.label.text;
					
			//	Add the bucket as a category
			args.result.xAxis.categories.push(label);

			//	Loop through each data series
			
			for (var i=0; i<args.result.series.length; i++) {

				//	Make sure each series has an array
				if (!allSeries[i]){
					allSeries[i] = [];
				}

				//	Get the data series, but skip nulls
				var data = $.grep(args.result.series[i].data, function(w){
					return w!==null;
				});
			
				if (data.length > 0) {
					//	Get the color
					var color = data[0].color ? data[0].color : args.result.series[i].color;

					//	Create new data obj
					var datapoint = {
						color: color,
						marker: data[0].marker,
						queryResultIndex: data[0].queryResultIndex,
						selected: false,
						selectionData: [label],
						selectedMembers: [],
						y:0
					};

					//	Loop through the original data series, save the value & member
					$.each(data, function(){		
						if (this.selectionData && this.selectionData[0] === label) {
							datapoint.y += this.y;
							datapoint.selectedMembers.push(this.selectionData[1]);
						}
					})

					//	Add new datapoint to series
					allSeries[i].push(datapoint);
				}
			}
		})	

		//	Replace the old data series'
		for (var j=0; j<args.result.series.length; j++) {
			args.result.series[j].data = null;
			args.result.series[j].data = allSeries[j];
		}

		//	Drop off the plotbands, since there's no more hierarchy
		args.result.xAxis.plotBands = [];
		args.result.xAxis.plotLines = [];
		
		//	Force chart settings
		widget.options.dashboardFiltersMode = "select";
		widget.options.selector = false;

		//	Create click handler function
		function chartClicked(event) {

			//	Get selected memmbers
			var members = event.point.selectedMembers;

			//	Get the jaql
			var widgetJaql = args.query.metadata[1].jaql;

			//	Create filter object
			var filter = {
				jaql: {
					column: widgetJaql.column,
					table: widgetJaql.table,
					dim: widgetJaql.dim,
					title: widgetJaql.title,
					datatype: widgetJaql.datatype,
					filter: {
						members: members
					}
				}
			};

			//	Create options for filter
			var options = {
				save:true, 
				refresh:true, 
				unionIfSameDimensionAndSameType:false
			};

			//	Set the filter
			prism.activeDashboard.filters.update(filter,options);
		}
		
		//	Add click handler to set filter	
		$.each(args.result.series, function(){
			this.events = {
				click: chartClicked
			};
		});
	});
}